@@ -16,9 +16,10 @@ shinyServer(function(input, output, session) {
       filter(color == selected_color) %>% 
       mutate(cut = stringr::str_to_sentence(cut)) %>%
       group_by(cut, clarity, .drop = FALSE) %>%
-      summarise(average_price = mean(price)) %>%
+      summarise(average_price = round(mean(price), 0)) %>%
       mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
-      ungroup()
+      mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
+      add_tip(c("cut", "clarity", "average_price"))
     
     return(plot_data)
   })
@@ -28,8 +29,7 @@ shinyServer(function(input, output, session) {
     # add plot code from make_data_vis.R
     # change any placeholder character values to input widgets
     # refer to a reactive plot_data object as plot_data()
-    # add isMobile = input$isMobile to simplevis functions, so that the plot looks good on a mobile
-    
+
     selected_color <- input$plot_color
     
     title <- paste0("Average diamond price of colour ", selected_color, " by cut and clarity")
@@ -39,11 +39,12 @@ shinyServer(function(input, output, session) {
     plot <- ggplot_hbar_col(data = plot_data(), 
                             x_var = average_price_thousands, 
                             y_var = cut, 
-                            col_var = clarity, 
+                            col_var = clarity,
+                            tip_var = tip_text,
                             legend_ncol = 4,
                             title = title, 
                             x_title = x_title, 
-                            y_title = y_title, 
+                            y_title = y_title,
                             isMobile = input$isMobile)
     
     
@@ -52,7 +53,7 @@ shinyServer(function(input, output, session) {
   
   output$plot_desktop <- plotly::renderPlotly({ 
     plotly::ggplotly(plot(), tooltip = "text") %>%
-      plotly_remove_buttons() 
+      plotly_camera() 
 
   })
   
