@@ -5,50 +5,58 @@ shinyServer(function(input, output, session) {
 
   # plot
 
-  plot_data <- reactive({ # create a reactive data object
-
-    ### add your plot_data code here ###
+  plot_data <- reactive({ # create a reactive plot_data object
+    
+    # add plot_data code from make_data_vis.R
+    # change any placeholder character values to input widgets
+    
     selected_color <- input$plot_color
     
-    plot_data <- df %>%
+    plot_data <- data %>%
       filter(color == selected_color) %>% 
       mutate(cut = stringr::str_to_sentence(cut)) %>%
       group_by(cut, clarity, .drop = FALSE) %>%
-      summarise(average_price = mean(price)) %>%
+      summarise(average_price = round(mean(price), 0)) %>%
       mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
-      ungroup()
-
+      mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
+      add_tip(c("cut", "clarity", "average_price"))
+    
     return(plot_data)
   })
-
+  
   plot <- reactive({ # create a reactive ggplot object
+    
+    # add plot code from make_data_vis.R
+    # change any placeholder character values to input widgets
+    # refer to a reactive plot_data object as plot_data()
 
-    ### add your plot code here ###
-    # remember to add isMobile = input$isMobile to simplevis functions, so that mobile plot looks good
-    # remember to refer to a reactive plot_data object as plot_data()
     selected_color <- input$plot_color
     
     title <- paste0("Average diamond price of colour ", selected_color, " by cut and clarity")
-      
+    x_title <- "Average price ($US thousands)"
+    y_title <- "Cut"
+    
     plot <- ggplot_hbar_col(data = plot_data(), 
                             x_var = average_price_thousands, 
                             y_var = cut, 
-                            col_var = clarity, 
+                            col_var = clarity,
+                            tip_var = tip_text,
                             legend_ncol = 4,
                             title = title, 
-                            x_title = "Average price ($US thousands)", 
-                            y_title = "Cut", 
+                            x_title = x_title, 
+                            y_title = y_title,
                             isMobile = input$isMobile)
     
-
+    
     return(plot)
   })
-
+  
   output$plot_desktop <- plotly::renderPlotly({ 
     plotly::ggplotly(plot(), tooltip = "text") %>%
-      plotly_remove_buttons()
-  })
+      plotly_camera() 
 
+  })
+  
   output$plot_mobile <- renderPlot({
     plot() +
       ggplot2::theme(plot.title.position = "plot") +
@@ -64,31 +72,20 @@ shinyServer(function(input, output, session) {
   output$table <- DT::renderDT(
     table_data(), 
     filter = "top",
-    rownames = F,
-    options = list(pageLength = 5, scrollX = T)
+    rownames = FALSE,
+    options = list(pageLength = 5, scrollX = TRUE)
   )
-
+  
   ### download ###
   
-  # use this code if one dataset
   output$download <- downloadHandler(
-    filename = function() {
-      "data.csv"
+    filename <- function() {
+      "data.zip"   # add data.zip into the data subfolder using code in get_app_data.R
     },
-    content = function(file) {
-      readr::write_csv(df, file, na = "") # adjust data object name, as necessary 
-    }
+    content <- function(file) {
+      file.copy("data/data.zip", file)
+    },
+    contentType = "application/zip"
   )
   
-  # use this code if multiple datasets
-  # output$download <- downloadHandler(
-  #   filename <- function() {
-  #     "data.zip"   # add a zip file called data.zip into the data subfolder
-  #   },
-  #   content <- function(file) {
-  #     file.copy("data/data.zip", file)
-  #   },
-  #   contentType = "application/zip"
-  # )
-  
 })
